==> apache-shenyu-incubating-2.4.1-src.zip: apache-shenyu-incubating-2.4.1-src/shenyu-plugin/shenyu-plugin-base/src/test/java/org/apache/shenyu/plugin/base/handler/PluginDataHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License,  Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,  software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,  either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.base.handler;

import org.apache.shenyu.common.dto.PluginData;
import org.apache.shenyu.common.dto.RuleData;
import org.apache.shenyu.common.dto.SelectorData;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.junit.MockitoJUnitRunner;

import java.util.HashMap;
import java.util.Map;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

/**
 * Test cases for PluginDataHandler.
 */
@RunWith(MockitoJUnitRunner.class)
public final class PluginDataHandlerTest {

    private RuleData ruleData;

    private PluginData pluginData;

    private SelectorData selectorData;

    private TestPluginDataHandler testPluginDataHandler;

    private PluginDataHandler pluginDataHandler;

    @Before
    public void setUp() {
        this.ruleData = mock(RuleData.class);
        this.pluginData = mock(PluginData.class);
        this.selectorData = mock(SelectorData.class);
        this.testPluginDataHandler = new TestPluginDataHandler();
        this.pluginDataHandler = new PluginDataHandler() {
            @Override
            public String pluginNamed() {
                return "SHENYU";
            }
        };
        when(ruleData.getId()).thenReturn("SHENYU");
        when(pluginData.getId()).thenReturn("SHENYU");
        when(selectorData.getId()).thenReturn("SHENYU");
    }

    /**
     * The handler plugin test.
     */
    @Test
    public void handlerPluginTest() {
        pluginDataHandler.handlerPlugin(pluginData);
        testPluginDataHandler.handlerPlugin(pluginData);
        Assert.assertEquals(testPluginDataHandler.getPluginDataMap().get(pluginData.getId()).getId(), pluginData.getId());
    }

    /**
     * The remove plugin test.
     */
    @Test
    public void removePluginTest() {
        pluginDataHandler.removePlugin(pluginData);
        testPluginDataHandler.handlerPlugin(pluginData);
        testPluginDataHandler.removePlugin(pluginData);
        Assert.assertNull(testPluginDataHandler.getPluginDataMap().get(pluginData.getId()));
    }

    /**
     * The handler selector test.
     */
    @Test
    public void handlerSelectorTest() {
        pluginDataHandler.handlerSelector(selectorData);
        testPluginDataHandler.handlerSelector(selectorData);
        Assert.assertEquals(testPluginDataHandler.getSelectorDataMap().get(selectorData.getId()).getId(), selectorData.getId());
    }

    /**
     * The remove selector test.
     */
    @Test
    public void removeSelectorTest() {
        pluginDataHandler.removeSelector(selectorData);
        testPluginDataHandler.handlerSelector(selectorData);
        testPluginDataHandler.removeSelector(selectorData);
        Assert.assertNull(testPluginDataHandler.getSelectorDataMap().get(selectorData.getId()));
    }

    /**
     * The handler rule test.
     */
    @Test
    public void handlerRuleTest() {
        pluginDataHandler.handlerRule(ruleData);
        testPluginDataHandler.handlerRule(ruleData);
        Assert.assertEquals(testPluginDataHandler.getRuleDataMap().get(ruleData.getId()).getId(), ruleData.getId());
    }

    /**
     * The remove rule test.
     */
    @Test
    public void removeRuleTest() {
        pluginDataHandler.removeRule(ruleData);
        testPluginDataHandler.handlerRule(ruleData);
        testPluginDataHandler.removeRule(ruleData);
        Assert.assertNull(testPluginDataHandler.getRuleDataMap().get(ruleData.getId()));
    }

    /**
     * The plugin named test.
     */
    @Test
    public void pluginNamedTest() {
        Assert.assertEquals("SHENYU", pluginDataHandler.pluginNamed());
        Assert.assertEquals("SHENYU_TEST", testPluginDataHandler.pluginNamed());
    }

    static class TestPluginDataHandler implements PluginDataHandler {

        private Map<String, PluginData> pluginDataMap = new HashMap<>();

        private Map<String, SelectorData> selectorDataMap = new HashMap<>();

        private Map<String, RuleData> ruleDataMap = new HashMap<>();

        public Map<String, PluginData> getPluginDataMap() {
            return pluginDataMap;
        }

        public void setPluginDataMap(final Map<String, PluginData> pluginDataMap) {
            this.pluginDataMap = pluginDataMap;
        }

        public Map<String, SelectorData> getSelectorDataMap() {
            return selectorDataMap;
        }

        public void setSelectorDataMap(final Map<String, SelectorData> selectorDataMap) {
            this.selectorDataMap = selectorDataMap;
        }

        public Map<String, RuleData> getRuleDataMap() {
            return ruleDataMap;
        }

        public void setRuleDataMap(final Map<String, RuleData> ruleDataMap) {
            this.ruleDataMap = ruleDataMap;
        }

        @Override
        public void handlerPlugin(final PluginData pluginData) {
            pluginDataMap.put(pluginData.getId(), pluginData);
        }

        @Override
        public void removePlugin(final PluginData pluginData) {
            pluginDataMap.remove(pluginData.getId());
        }

        @Override
        public void handlerSelector(final SelectorData selectorData) {
            selectorDataMap.put(selectorData.getId(), selectorData);
        }

        @Override
        public void removeSelector(final SelectorData selectorData) {
            selectorDataMap.remove(selectorData.getId());
        }

        @Override
        public void handlerRule(final RuleData ruleData) {
            ruleDataMap.put(ruleData.getId(), ruleData);
        }

        @Override
        public void removeRule(final RuleData ruleData) {
            ruleDataMap.remove(ruleData.getId());
        }

        @Override
        public String pluginNamed() {
            return "SHENYU_TEST";
        }
    }
}

==> apache-shenyu-incubating-2.4.2-src.zip: apache-shenyu-incubating-2.4.2-src/shenyu-plugin/shenyu-plugin-base/src/test/java/org/apache/shenyu/plugin/base/handler/PluginDataHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License,  Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,  software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,  either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.base.handler;

import org.apache.shenyu.common.dto.PluginData;
import org.apache.shenyu.common.dto.RuleData;
import org.apache.shenyu.common.dto.SelectorData;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.junit.MockitoJUnitRunner;

import java.util.HashMap;
import java.util.Map;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

/**
 * Test cases for PluginDataHandler.
 */
@RunWith(MockitoJUnitRunner.class)
public final class PluginDataHandlerTest {

    private RuleData ruleData;

    private PluginData pluginData;

    private SelectorData selectorData;

    private TestPluginDataHandler testPluginDataHandler;

    private PluginDataHandler pluginDataHandler;

    @Before
    public void setUp() {
        this.ruleData = mock(RuleData.class);
        this.pluginData = mock(PluginData.class);
        this.selectorData = mock(SelectorData.class);
        this.testPluginDataHandler = new TestPluginDataHandler();
        this.pluginDataHandler = () -> "SHENYU";
        when(ruleData.getId()).thenReturn("SHENYU");
        when(pluginData.getId()).thenReturn("SHENYU");
        when(selectorData.getId()).thenReturn("SHENYU");
    }

    /**
     * The handler plugin test.
     */
    @Test
    public void handlerPluginTest() {
        pluginDataHandler.handlerPlugin(pluginData);
        testPluginDataHandler.handlerPlugin(pluginData);
        Assert.assertEquals(testPluginDataHandler.getPluginDataMap().get(pluginData.getId()).getId(), pluginData.getId());
    }

    /**
     * The remove plugin test.
     */
    @Test
    public void removePluginTest() {
        pluginDataHandler.removePlugin(pluginData);
        testPluginDataHandler.handlerPlugin(pluginData);
        testPluginDataHandler.removePlugin(pluginData);
        Assert.assertNull(testPluginDataHandler.getPluginDataMap().get(pluginData.getId()));
    }

    /**
     * The handler selector test.
     */
    @Test
    public void handlerSelectorTest() {
        pluginDataHandler.handlerSelector(selectorData);
        testPluginDataHandler.handlerSelector(selectorData);
        Assert.assertEquals(testPluginDataHandler.getSelectorDataMap().get(selectorData.getId()).getId(), selectorData.getId());
    }

    /**
     * The remove selector test.
     */
    @Test
    public void removeSelectorTest() {
        pluginDataHandler.removeSelector(selectorData);
        testPluginDataHandler.handlerSelector(selectorData);
        testPluginDataHandler.removeSelector(selectorData);
        Assert.assertNull(testPluginDataHandler.getSelectorDataMap().get(selectorData.getId()));
    }

    /**
     * The handler rule test.
     */
    @Test
    public void handlerRuleTest() {
        pluginDataHandler.handlerRule(ruleData);
        testPluginDataHandler.handlerRule(ruleData);
        Assert.assertEquals(testPluginDataHandler.getRuleDataMap().get(ruleData.getId()).getId(), ruleData.getId());
    }

    /**
     * The remove rule test.
     */
    @Test
    public void removeRuleTest() {
        pluginDataHandler.removeRule(ruleData);
        testPluginDataHandler.handlerRule(ruleData);
        testPluginDataHandler.removeRule(ruleData);
        Assert.assertNull(testPluginDataHandler.getRuleDataMap().get(ruleData.getId()));
    }

    /**
     * The plugin named test.
     */
    @Test
    public void pluginNamedTest() {
        Assert.assertEquals("SHENYU", pluginDataHandler.pluginNamed());
        Assert.assertEquals("SHENYU_TEST", testPluginDataHandler.pluginNamed());
    }

    static class TestPluginDataHandler implements PluginDataHandler {

        private Map<String, PluginData> pluginDataMap = new HashMap<>();

        private Map<String, SelectorData> selectorDataMap = new HashMap<>();

        private Map<String, RuleData> ruleDataMap = new HashMap<>();

        public Map<String, PluginData> getPluginDataMap() {
            return pluginDataMap;
        }

        public void setPluginDataMap(final Map<String, PluginData> pluginDataMap) {
            this.pluginDataMap = pluginDataMap;
        }

        public Map<String, SelectorData> getSelectorDataMap() {
            return selectorDataMap;
        }

        public void setSelectorDataMap(final Map<String, SelectorData> selectorDataMap) {
            this.selectorDataMap = selectorDataMap;
        }

        public Map<String, RuleData> getRuleDataMap() {
            return ruleDataMap;
        }

        public void setRuleDataMap(final Map<String, RuleData> ruleDataMap) {
            this.ruleDataMap = ruleDataMap;
        }

        @Override
        public void handlerPlugin(final PluginData pluginData) {
            pluginDataMap.put(pluginData.getId(), pluginData);
        }

        @Override
        public void removePlugin(final PluginData pluginData) {
            pluginDataMap.remove(pluginData.getId());
        }

        @Override
        public void handlerSelector(final SelectorData selectorData) {
            selectorDataMap.put(selectorData.getId(), selectorData);
        }

        @Override
        public void removeSelector(final SelectorData selectorData) {
            selectorDataMap.remove(selectorData.getId());
        }

        @Override
        public void handlerRule(final RuleData ruleData) {
            ruleDataMap.put(ruleData.getId(), ruleData);
        }

        @Override
        public void removeRule(final RuleData ruleData) {
            ruleDataMap.remove(ruleData.getId());
        }

        @Override
        public String pluginNamed() {
            return "SHENYU_TEST";
        }
    }
}
